create_fail_reporter: Create Fail Reporter

View source: R/run_covr_skip_stf.R

create_fail_reporterR Documentation

Create Fail Reporter

Description

Executes all tests in a given directory using 'testthat::test_dir()' and applies context fixes to ensure each test has a valid context.

Usage

create_fail_reporter(test_path, pkg)

Arguments

test_path

Character string specifying the path to the test directory.

pkg

Character string specifying the package name.

Value

A list of test results with corrected contexts, or 'NULL' if an error occurs.


test.assessr documentation built on March 3, 2026, 1:06 a.m.