create_test_reporter: Create Test Reporter

View source: R/run_covr_skip_stf.R

create_test_reporterR Documentation

Create Test Reporter

Description

Executes all tests in a given directory using 'testthat::test_dir()' and applies context fixes to ensure each test has a valid context.

Usage

create_test_reporter(test_path, pkg)

Arguments

test_path

Character string specifying the path to the test directory.

pkg

Character string specifying the package name.

Value

A list of test results with corrected contexts, or 'NULL' if an error occurs.


test.assessr documentation built on March 3, 2026, 1:06 a.m.