detect_frameworks: Detect which test frameworks are present in a package

View source: R/run_covr_modes.R

detect_frameworksR Documentation

Detect which test frameworks are present in a package

Description

Detect which test frameworks are present in a package

Usage

detect_frameworks(test_pkg_data)

Arguments

test_pkg_data

List from check_pkg_tests_and_snaps.

Value

Character vector of framework IDs: "testthat", "testit", "tests_base", "tinytest", "data.table", "bioconductor".


test.assessr documentation built on April 30, 2026, 5:06 p.m.