fix_test_context: Fix Missing Test Contexts

View source: R/run_covr_skip_stf.R

fix_test_contextR Documentation

Fix Missing Test Contexts

Description

Ensures that each test result has a valid 'context' field. If missing or empty, the context is set to the file name (without extension).

Usage

fix_test_context(test_results)

Arguments

test_results

A list of test result objects from 'testthat'.

Value

A list of test results with updated contexts.


test.assessr documentation built on April 30, 2026, 5:06 p.m.