View source: R/generate_test_report.R
| generate_test_report | R Documentation |
Generates an HTML report for the package test assessment results using rmarkdown.
generate_test_report(test_results, output_dir = NULL)
test_results |
List containing the results from get_package_coverage function. |
output_dir |
(required) Character string path to an existing directory where the report will be saved. |
Path to the generated HTML report.
## Not run:
test_results <- get_package_coverage()
# Always provide a directory; tempdir() is convenient in examples.
generate_test_report(test_results, output_dir = tempdir())
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.