get_pkg_desc: Read Description file and parse the package name and version

View source: R/utils.R

get_pkg_descR Documentation

Read Description file and parse the package name and version

Description

Read Description file and parse the package name and version

Usage

get_pkg_desc(pkg_source_path, fields = NULL)

Arguments

pkg_source_path

path to package source code (untarred)

fields

- select specified elements from description

Value

list with package description


test.assessr documentation built on March 3, 2026, 1:06 a.m.