get_source_test_mapping_Bioc_nstf: Map Bioconductor source files to test files, avoiding false...

View source: R/run_covr_skip_bioc_nstf.R

get_source_test_mapping_Bioc_nstfR Documentation

Map Bioconductor source files to test files, avoiding false positives. Tightens filename and content-based matching; handles short names like "t".

Description

Map Bioconductor source files to test files, avoiding false positives. Tightens filename and content-based matching; handles short names like "t".

Usage

get_source_test_mapping_Bioc_nstf(pkg_source_path, test_dir)

Arguments

pkg_source_path

Character; path to the package root (expects R/ under it).

test_dir

Character; path to tests directory (e.g., file.path(pkg, "tests"))

Value

data.frame with columns: source_file, test_file, evidence, has_tests


test.assessr documentation built on March 3, 2026, 1:06 a.m.