get_tests_long_sum_stf: Summarize detailed testthat results

View source: R/get_tests_long_sum_stf.R

get_tests_long_sum_stfR Documentation

Summarize detailed testthat results

Description

Internal helper function to generate a long-format summary of testthat results, including status and line references.

Usage

get_tests_long_sum_stf(x)

Arguments

x

list of test result objects

Value

data.frame with detailed test results including status and source line links


test.assessr documentation built on March 3, 2026, 1:06 a.m.