get_tests_skip_stf: Safely generate skip test mapping from problem tests and test...

View source: R/get_tests_skip_stf.R

get_tests_skip_stfR Documentation

Safely generate skip test mapping from problem tests and test map

Description

This function filters and joins test metadata to identify which tests should be skipped based on failed or problematic test results.

Usage

get_tests_skip_stf(problem_tests, test_map)

Arguments

problem_tests

A data frame of problematic tests, including columns 'file' and 'context'.

test_map

A data frame representing the test structure, including columns 'file' and 'context'.

Value

A data frame containing the merged skip test mapping, or 'NULL' if validation or processing fails.


test.assessr documentation built on March 3, 2026, 1:06 a.m.