View source: R/run_covr_skip_bioc_nstf.R
| check_covr_skip_Bioc_nstf | R Documentation |
This internal function attempts to run test files mapped to source files and identifies any that produce warnings or errors. It does not handle 'testit'.
check_covr_skip_Bioc_nstf(pkg_source_path, mapping, test_path)
pkg_source_path |
Path to the root of the package source. |
mapping |
A data frame with a column 'test_file' listing test file names. |
test_path |
directory |
A data frame listing test files and any issues encountered.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.