Learn R Programming

test.assessr (version 1.1.1)

check_covr_skip_Bioc_nstf: Check for skipped or errored test files (BiocGenerics)

Description

This internal function attempts to run test files mapped to source files and identifies any that produce warnings or errors. It does not handle `testit`.

Usage

check_covr_skip_Bioc_nstf(pkg_source_path, mapping, test_path)

Value

A data frame listing test files and any issues encountered.

Arguments

pkg_source_path

Path to the root of the package source.

mapping

A data frame with a column `test_file` listing test file names.

test_path

directory