This internal function attempts to run test files mapped to source files and identifies any that produce warnings or errors. It does not handle `testit`.
check_covr_skip_Bioc_nstf(pkg_source_path, mapping, test_path)A data frame listing test files and any issues encountered.
Path to the root of the package source.
A data frame with a column `test_file` listing test file names.
directory