View source: R/run_covr_skip_nstf.R
| check_covr_skip_testit | R Documentation |
Run testit tests individually, capturing all warnings and errors, with dynamic package root detection
check_covr_skip_testit(pkg_name, mapping, test_path)
pkg_name |
The package name (not used in this function, but kept for compatibility) |
mapping |
A data frame with a column 'test_file' listing test file names |
test_path |
The path to the test directory (e.g., tests/testit) |
A data frame with test_file and issue_type columns
Other nstf_utility:
create_base_tests_coverage(),
create_nstf_covr_list(),
create_tinytest_coverage(),
get_nstf_test_path(),
get_source_test_mapping_nstf(),
restrict_test_paths_to_framework(),
run_covr_skip_nstf()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.