Run testit tests individually, capturing all warnings and errors, with dynamic package root detection
check_covr_skip_testit(pkg_name, mapping, test_path)A data frame with test_file and issue_type columns
The package name (not used in this function, but kept for compatibility)
A data frame with a column `test_file` listing test file names
The path to the test directory (e.g., tests/testit)
Other nstf_utility:
create_base_tests_coverage(),
create_nstf_covr_list(),
create_tinytest_coverage(),
get_nstf_test_path(),
get_source_test_mapping_nstf(),
restrict_test_paths_to_framework(),
run_covr_skip_nstf()