View source: R/generate_test_report.R
| check_elements_simple | R Documentation |
This internal function checks whether specified elements exist in a given list
and returns two vectors: elements that exist and elements that do not. When
nested = TRUE and x has results (multi-framework), checks
inside each x$results$<framework>.
check_elements_simple(x, elems, nested = FALSE)
x |
A list object to check (e.g., 'test_results'). |
elems |
A character vector of element names to check. |
nested |
If TRUE and |
A list with:
Character vector of elements that exist.
Character vector of elements that do not exist (top-level only).
Named list (framework -> present elements), when nested.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.