View source: R/generate_test_report.R
| check_elements_simple | R Documentation |
This internal function checks whether specified elements exist in a given list and returns two vectors: elements that exist and elements that do not.
check_elements_simple(x, elems)
x |
A list object to check (e.g., 'test_results'). |
elems |
A character vector of element names to check. |
A list with:
Character vector of elements that exist in the list.
Character vector of elements that do not exist in the list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.