This internal function checks whether specified elements exist in a given list and returns two vectors: elements that exist and elements that do not.
check_elements_simple(x, elems)A list with:
Character vector of elements that exist in the list.
Character vector of elements that do not exist in the list.
A list object to check (e.g., `test_results`).
A character vector of element names to check.