View source: R/run_covr_modes.R
| cleanup_and_return_null | R Documentation |
This internal utility function is used to clean up the cov environment by removing all objects and optionally displaying a message before returning 'NULL'. It is primarily used within 'run_coverage_base()' to ensure consistent cleanup in error-handling scenarios.
cleanup_and_return_null(msg = NULL, env = cov_env)
msg |
Optional character string. If provided, the message will be printed before cleanup. |
env |
A character string specifying the covr env |
NULL (invisibly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.