View source: R/generate_test_report.R
| convert_vectors_to_df | R Documentation |
This internal function takes named character vectors (e.g., 'tests_skipped', 'tests_passing') from a list and converts them into data frames for easier reporting or processing.
convert_vectors_to_df(x, elems)
x |
A list containing character vectors (e.g., 'test_results'). |
elems |
A character vector of element names to convert (must exist in 'x'). |
A named list of data frames, where each data frame has one column:
The file names or paths from the original character vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.