View source: R/run_covr_skip_stf.R
| create_fail_reporter | R Documentation |
Executes all tests in a given directory using 'testthat::test_dir()' and applies context fixes to ensure each test has a valid context.
create_fail_reporter(test_path, pkg)
test_path |
Character string specifying the path to the test directory. |
pkg |
Character string specifying the package name. |
A list of test results with corrected contexts, or 'NULL' if an error occurs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.