Learn R Programming

test.assessr (version 1.1.1)

create_test_reporter: Create Test Reporter

Description

Executes all tests in a given directory using `testthat::test_dir()` and applies context fixes to ensure each test has a valid context.

Usage

create_test_reporter(test_path, pkg)

Value

A list of test results with corrected contexts, or `NULL` if an error occurs.

Arguments

test_path

Character string specifying the path to the test directory.

pkg

Character string specifying the package name.