Helper to extract "R/<file>" from any path by taking the last two components
Source:R/utils.R
extract_short_path.RdHelper to extract "R/<file>" from any path by taking the last two components
R/utils.R
extract_short_path.RdHelper to extract "R/<file>" from any path by taking the last two components