extract_short_path: Helper to extract "R/<file>" from any path by taking the last...

View source: R/utils.R

extract_short_pathR Documentation

Helper to extract "R/<file>" from any path by taking the last two components

Description

Helper to extract "R/<file>" from any path by taking the last two components

Usage

extract_short_path(long_file_name)

Arguments

long_file_name

A string containing the full file path (supports '/' or '\')

Value

A character string composed of the last two path components, e.g., "R/add.R"


test.assessr documentation built on April 30, 2026, 5:06 p.m.