| extract_short_path | R Documentation |
Helper to extract "R/<file>" from any path by taking the last two components
extract_short_path(long_file_name)
long_file_name |
A string containing the full file path (supports '/' or '\') |
A character string composed of the last two path components, e.g., "R/add.R"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.