extract_short_path: Helper to extract "R/<file>" from any path by taking the last two components
Description
Helper to extract "R/<file>" from any path by taking the last two components
Usage
extract_short_path(long_file_name)
Value
A character string composed of the last two path components, e.g., "R/add.R"
Arguments
- long_file_name
A string containing the full file path (supports '/' or '\')