View source: R/run_covr_skip_stf.R
| fix_test_context | R Documentation |
Ensures that each test result has a valid 'context' field. If missing or empty, the context is set to the file name (without extension).
fix_test_context(test_results)
test_results |
A list of test result objects from 'testthat'. |
A list of test results with updated contexts.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.