Learn R Programming

test.assessr (version 2.1.2)

fix_test_context: Fix Missing Test Contexts

Description

Ensures that each test result has a valid `context` field. If missing or empty, the context is set to the file name (without extension).

Usage

fix_test_context(test_results)

Value

A list of test results with updated contexts.

Arguments

test_results

A list of test result objects from `testthat`.