View source: R/run_covr_skip_nstf.R
| get_source_test_mapping_nstf | R Documentation |
This internal helper function scans the 'R/' and 'tests/' directories of a package and attempts to match each source file with a corresponding test file based on filename similarity.
get_source_test_mapping_nstf(pkg_source_path, test_dir)
pkg_source_path |
Character string. Path to the root of the package source directory. |
test_dir |
character string. directory where tests are |
A data frame with two columns:
Name of the source file in the 'R/' directory.
Name of the matched test file in the 'tests/' directory, or NA if no match is found.
Other nstf_utility:
check_covr_skip_testit(),
create_base_tests_coverage(),
create_nstf_covr_list(),
create_tinytest_coverage(),
get_nstf_test_path(),
restrict_test_paths_to_framework(),
run_covr_skip_nstf()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.