This internal helper function scans the `R/` and `tests/` directories of a package and attempts to match each source file with a corresponding test file based on filename similarity.
get_source_test_mapping_nstf(pkg_source_path, test_dir)A data frame with two columns:
Name of the source file in the `R/` directory.
Name of the matched test file in the `tests/` directory, or NA if no match is found.
Character string. Path to the root of the package source directory.
character string. directory where tests are
Other nstf_utility:
check_covr_skip_testit(),
create_base_tests_coverage(),
create_nstf_covr_list(),
create_tinytest_coverage(),
get_nstf_test_path(),
restrict_test_paths_to_framework(),
run_covr_skip_nstf()