View source: R/get_tests_long_sum_stf.R
| get_tests_long_sum_stf | R Documentation |
Internal helper function to generate a long-format summary of testthat results, including status and line references.
get_tests_long_sum_stf(x)
x |
list of test result objects |
data.frame with detailed test results including status and source line links
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.