Learn R Programming

test.assessr (version 1.1.1)

get_tests_long_sum_stf: Summarize detailed testthat results

Description

Internal helper function to generate a long-format summary of testthat results, including status and line references.

Usage

get_tests_long_sum_stf(x)

Value

data.frame with detailed test results including status and source line links

Arguments

x

list of test result objects