load_package_datasets: Load Datasets from a Package

View source: R/run_covr_modes.R

load_package_datasetsR Documentation

Load Datasets from a Package

Description

Loads all datasets from a specified installed package into the cov environment. It first attempts to load ‘.rda' files from the package’s 'data/' directory. If none are found, it falls back to using 'data()' to load datasets listed in the package metadata.

Usage

load_package_datasets(pkg_name, env = cov_env)

Arguments

pkg_name

A character string specifying the name of the package.

env

A character string specifying the covr env

Details

This function is intended for internal use. It silently attempts to load each dataset and suppresses errors if loading fails. Datasets are loaded into the cov environment.

Value

A character vector of dataset names that were attempted to be loaded. Returns 'NULL' if the package is not installed.


test.assessr documentation built on March 3, 2026, 1:06 a.m.