View source: R/run_covr_modes.R
| load_package_datasets | R Documentation |
Loads all datasets from a specified installed package into the cov environment. It first attempts to load ‘.rda' files from the package’s 'data/' directory. If none are found, it falls back to using 'data()' to load datasets listed in the package metadata.
load_package_datasets(pkg_name, env = cov_env)
pkg_name |
A character string specifying the name of the package. |
env |
A character string specifying the covr env |
This function is intended for internal use. It silently attempts to load each dataset and suppresses errors if loading fails. Datasets are loaded into the cov environment.
A character vector of dataset names that were attempted to be loaded. Returns 'NULL' if the package is not installed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.