This function maps source files to test files, checks for skipped/problematic tests, runs the remaining test files manually, calculates coverage, and optionally generates a report.
run_covr_skip_dt_nstf(pkg_source_path, test_pkg_data, cov_env)returns a list with coverage object and source files with no tests.
Character string. Path to the root of the package source directory.
List. Output from `check_pkg_tests_and_snaps()` indicating test framework presence.
Environment that holds the temporary coverage workspace and shared state for the run.