View source: R/run_covr_modes.R
| safe_unload_package | R Documentation |
This internal function attempts to unload a specified package if it is currently loaded. It is used to prevent coverage conflicts when reloading the package in a custom environment.
safe_unload_package(pkg)
pkg |
Character string. The name of the package to unload. |
NULL (invisibly). Messages are printed to indicate success or failure.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.