safe_unload_package: Safely unload a package to avoid coverage conflicts
Description
This internal function attempts to unload a specified package if it is currently loaded.
It is used to prevent coverage conflicts when reloading the package in a custom environment.
Usage
safe_unload_package(pkg)
Value
NULL (invisibly). Messages are printed to indicate success or failure.
Arguments
pkg
Character string. The name of the package to unload.